==> orlo-0.4.0.tar.gz: orlo-0.4.0/tests/test_route_packages.py <==
from __future__ import print_function
from test_route_base import OrloHttpTest
import json

__author__ = 'alforbes'


class GetPackagesTest(OrloHttpTest):
    """
    Test the HTTP GET contract
    """

    def _get_packages(self, package_id=None, filters=None, expected_status=200):
        """
        Perform a GET to /releases with optional filters
        """

        if package_id:
            path = '/packages/{}'.format(package_id)
        elif filters:
            path = '/packages?{}'.format('&'.join(filters))
        else:
            path = '/packages'

        results_response = self.client.get(
            path, content_type='application/json',
        )

        try:
            self.assertEqual(results_response.status_code, expected_status)
        except AssertionError as err:
            print(results_response.data)
            raise
        r_json = json.loads(results_response.data.decode('utf-8'))
        return r_json

    def test_packages(self):
        """
        Test that we get 400 and a message with no params
        """
        response = self.client.get('/packages')
        self.assert400(response)
        self.assertIn('message', response.json)

    def test_get_single_package(self):
        """
        Fetch a single release
        """
        release_id = self._create_release()
        package_id = self._create_package(release_id)
        p = self._get_packages(package_id=package_id)
        self.assertEqual(1, len(p['packages']))
        self.assertEqual(package_id, p['packages'][0]['id'])

    def test_get_package_multiple(self):
        """
        Fetch multiple packages
        """
        for _ in range(0, 3):
            self._create_finished_release()
        p = self._get_packages(filters=['name=test-package'])
        self.assertIsInstance(p['packages'], list)
        self.assertEqual(3, len(p['packages']))

==> orlo-0.4.3.tar.gz: orlo-0.4.3/tests/test_route_packages.py <==
from __future__ import print_function
from test_route_base import OrloHttpTest
import json
import uuid

__author__ = 'alforbes'


class GetPackagesTest(OrloHttpTest):
    """
    Test the HTTP GET contract
    """

    def _get_packages(self, package_id=None, filters=None, expected_status=200):
        """
        Perform a GET to /packages with optional filters
        """

        if package_id:
            path = '/packages/{}'.format(package_id)
        elif filters:
            path = '/packages?{}'.format('&'.join(filters))
        else:
            path = '/packages'

        results_response = self.client.get(
            path, content_type='application/json',
        )

        try:
            self.assertEqual(results_response.status_code, expected_status)
        except AssertionError as err:
            print(results_response.data)
            raise
        r_json = json.loads(results_response.data.decode('utf-8'))
        return r_json

    def test_packages_invalid_uuid_returns_400(self):
        """
        Test that we get 400 with an invald uuid
        """
        response = self.client.get('/packages/not-a-valid-uuid')
        self.assert400(response)
        self.assertIn('message', response.json)

    def test_packages_missing_package_returns_404(self):
        """
        Test that we get 404 when there are no packages
        """
        response = self.client.get('/packages/{}'.format(uuid.uuid4()))
        self.assert404(response)
        self.assertIn('message', response.json)

    def test_get_single_package(self):
        """
        Fetch a single release
        """
        release_id = self._create_release()
        package_id = self._create_package(release_id)
        p = self._get_packages(package_id=package_id)
        self.assertEqual(1, len(p['packages']))
        self.assertEqual(package_id, p['packages'][0]['id'])

    def test_get_package_multiple(self):
        """
        Fetch multiple packages
        """
        for _ in range(0, 3):
            self._create_finished_release()
        p = self._get_packages(filters=['name=test-package'])
        self.assertIsInstance(p['packages'], list)
        self.assertEqual(3, len(p['packages']))
